# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.attached_file import AttachedFile
from public_api_server_connector_v2.models.content_block import ContentBlock
from public_api_server_connector_v2.models.lesson_type_str_enum import LessonTypeStrEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ModuleLesson(BaseModel):
    """
    ModuleLesson
    """ # noqa: E501
    submodule_id: Optional[StrictInt] = Field(default=None, description="ID of the submodule this lesson belongs to, if not part of submodule, it is null, defaults to null")
    thread_id: Optional[StrictInt] = Field(default=None, description="ID of the community thread this lesson belongs to, if not part of thread, it is null, defaults to null")
    lesson_type: LessonTypeStrEnum = Field(description="Type of the lesson")
    image_id: Optional[StrictStr] = Field(default=None, description="ID of the image associated with the lesson")
    title: StrictStr = Field(description="Title of the lesson")
    payload: Optional[StrictStr] = Field(default='', description="Payload of the lesson, e.g. description or summary")
    is_active: StrictBool = Field(description="Whether the lesson is active or not")
    is_published: StrictBool = Field(description="Whether the lesson is published or not")
    mandatory: StrictBool = Field(description="Whether the lesson is mandatory to complete the module or not")
    id: StrictInt = Field(description="ID of the lesson")
    module_id: StrictInt = Field(description="ID of the module this lesson belongs to")
    order: StrictInt = Field(description="Order of the lesson in the module")
    public_key: Optional[StrictStr] = Field(default=None, description="Public key of the lesson, can be used to access the lesson without authentication")
    content_blocks: List[ContentBlock] = Field(description="List of content blocks in the lesson")
    attached_files: List[AttachedFile] = Field(description="List of attached files in the lesson")
    __properties: ClassVar[List[str]] = ["submodule_id", "thread_id", "lesson_type", "image_id", "title", "payload", "is_active", "is_published", "mandatory", "id", "module_id", "order", "public_key", "content_blocks", "attached_files"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModuleLesson from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in content_blocks (list)
        _items = []
        if self.content_blocks:
            for _item_content_blocks in self.content_blocks:
                if _item_content_blocks:
                    _items.append(_item_content_blocks.to_dict())
            _dict['content_blocks'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attached_files (list)
        _items = []
        if self.attached_files:
            for _item_attached_files in self.attached_files:
                if _item_attached_files:
                    _items.append(_item_attached_files.to_dict())
            _dict['attached_files'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModuleLesson from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "submodule_id": obj.get("submodule_id"),
            "thread_id": obj.get("thread_id"),
            "lesson_type": obj.get("lesson_type"),
            "image_id": obj.get("image_id"),
            "title": obj.get("title"),
            "payload": obj.get("payload") if obj.get("payload") is not None else '',
            "is_active": obj.get("is_active"),
            "is_published": obj.get("is_published"),
            "mandatory": obj.get("mandatory"),
            "id": obj.get("id"),
            "module_id": obj.get("module_id"),
            "order": obj.get("order"),
            "public_key": obj.get("public_key"),
            "content_blocks": [ContentBlock.from_dict(_item) for _item in obj["content_blocks"]] if obj.get("content_blocks") is not None else None,
            "attached_files": [AttachedFile.from_dict(_item) for _item in obj["attached_files"]] if obj.get("attached_files") is not None else None
        })
        return _obj


