# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.category_permissions import CategoryPermissions
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ApiKeyGet(BaseModel):
    """
    ApiKeyGet
    """ # noqa: E501
    name: StrictStr
    id: StrictInt
    portal_id: StrictInt
    permissions: Optional[Dict[str, CategoryPermissions]] = Field(default=None, description="Permissions for each category, where the key is the category name and the value is the permissions.")
    openapi_specification_url: Optional[StrictStr] = Field(default='', description="URL to the OpenAPI specification with a permission_filter query parameter.")
    created_at: StrictInt
    last_used_at: Optional[StrictInt] = None
    updated_at: Optional[StrictInt] = None
    expires_at: Optional[StrictInt] = None
    revoked_at: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["name", "id", "portal_id", "permissions", "openapi_specification_url", "created_at", "last_used_at", "updated_at", "expires_at", "revoked_at"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiKeyGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in permissions (dict)
        _field_dict = {}
        if self.permissions:
            for _key_permissions in self.permissions:
                if self.permissions[_key_permissions]:
                    _field_dict[_key_permissions] = self.permissions[_key_permissions].to_dict()
            _dict['permissions'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiKeyGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "id": obj.get("id"),
            "portal_id": obj.get("portal_id"),
            "permissions": dict(
                (_k, CategoryPermissions.from_dict(_v))
                for _k, _v in obj["permissions"].items()
            )
            if obj.get("permissions") is not None
            else None,
            "openapi_specification_url": obj.get("openapi_specification_url") if obj.get("openapi_specification_url") is not None else '',
            "created_at": obj.get("created_at"),
            "last_used_at": obj.get("last_used_at"),
            "updated_at": obj.get("updated_at"),
            "expires_at": obj.get("expires_at"),
            "revoked_at": obj.get("revoked_at")
        })
        return _obj


