# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.content import Content

class TestContent(unittest.TestCase):
    """Content unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Content:
        """Test Content
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Content`
        """
        model = Content()
        if include_optional:
            return Content(
                link = '',
                file_id = '',
                audio_id = '',
                payload = '',
                btn_url = '',
                btn_font = '',
                btn_size = 'small',
                btn_text = '',
                btn_color = '',
                btn_target = '_self',
                btn_position = 'left',
                btn_text_color = '',
                pdf_id = ''
            )
        else:
            return Content(
        )
        """

    def testContent(self):
        """Test Content"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
